==> netdude_0.3.3.orig.tar.gz: netdude-0.3.3/protocols/linux-sll/nd_sll_callbacks.h <==
/*

Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

#ifndef __nd_sll_callbacks_h
#define __nd_sll_callbacks_h

#include <netdude/nd_packet.h>
#include <netdude/nd_trace.h>
#include <netdude/nd_packet.h>

/* Button callbacks */

void    nd_sll_pkttype_cb(ND_Packet   *packet,
			  guchar      *header,
			  guchar      *data);

void    nd_sll_hatype_cb(ND_Packet   *packet,
			 guchar      *header,
			 guchar      *data);

void    nd_sll_halen_cb(ND_Packet   *packet,
			guchar      *header,
			guchar      *data);

void    nd_sll_addr_cb(ND_Packet   *packet,
		       guchar      *header,
		       guchar      *data);

void    nd_sll_proto_cb(ND_Packet   *packet,
			guchar      *header,
			guchar      *data);


#endif

==> netdude-0.4.6.tar.gz: netdude-0.4.6/protocols/linux-sll/nd_sll_callbacks.h <==
/*

Copyright (C) 2000 - 2003 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/

#ifndef __nd_sll_callbacks_h
#define __nd_sll_callbacks_h

#include <nd_packet.h>
#include <nd_trace.h>
#include <nd_packet.h>

/* Button callbacks */

void    nd_sll_pkttype_cb(LND_Packet   *packet,
			  guchar       *header,
			  guchar       *data);

void    nd_sll_hatype_cb(LND_Packet   *packet,
			 guchar       *header,
			 guchar       *data);

void    nd_sll_halen_cb(LND_Packet   *packet,
			guchar       *header,
			guchar       *data);

void    nd_sll_addr_cb(LND_Packet   *packet,
		       guchar       *header,
		       guchar       *data);

void    nd_sll_proto_cb(LND_Packet   *packet,
			guchar       *header,
			guchar       *data);


#endif
